CKEDITOR.plugins.setLang('youtube', 'uk', {
	button : 'Вставити YouTube-відео',
	title : 'Вставити YouTube-відео',
	txtEmbed : 'Вставте HTML-код сюди',
	txtUrl : 'Вставте URL-адресу сюди',
	txtWidth : 'Ширина',
	txtHeight : 'Висота',
	chkRelated : 'Показати пропоновані відео в кінці',
	txtStartAt : 'Почати з (сс або хх:сс або гг:хх:сс)',
	chkPrivacy : 'Увімкнути режим підвищеної конфіденційності',
	chkOlderCode : 'Використовувати старий код вставки',
	chkAutoplay: 'Автовідтворення',
	chkControls: 'Показувати елементи управління плеєром',
	noCode : 'Ви повинні ввести HTML-код або URL-адресу',
	invalidEmbed : 'Код вставки, який ви додали не вірний',
	invalidUrl : 'URL-адреса, яку ви додали не вірна',
	or : 'або',
	noWidth : 'Укажіть ширину',
	invalidWidth : 'Укажіть правильну ширину',
	noHeight : 'Укажіть висоту',
	invalidHeight : 'Укажіть правильну висоту',
	invalidTime : 'Укажіть правильний час початку',
	txtResponsive : 'Адаптивне (таке, яке розтягується) відео',
	txtNoEmbed : 'Додати лише обкладинку та посилання на YouTube'
});
